@@ -16,3 +16,5 @@ DECLARE_CALL(igd_plus_C, SEXP DATA, SEXP REFERENCE, SEXP MAXIMISE)
 DECLARE_CALL(avg_hausdorff_dist_C, SEXP DATA, SEXP REFERENCE, SEXP MAXIMISE, SEXP P)
 DECLARE_CALL(rect_weighted_hv2d_C, SEXP DATA, SEXP RECTANGLES, SEXP REFERENCE)
 DECLARE_CALL(whv_hype_C, SEXP DATA, SEXP IDEAL, SEXP REFERENCE, SEXP NSAMPLES, SEXP DIST, SEXP SEED, SEXP MU)
+DECLARE_CALL(hv_approx_dz2019_mc_C, SEXP DATA, SEXP REFERENCE, SEXP MAXIMISE, SEXP NSAMPLES, SEXP SEED)
+DECLARE_CALL(hv_approx_dz2019_hw_C, SEXP DATA, SEXP REFERENCE, SEXP MAXIMISE, SEXP NSAMPLES)
