@@ -135,18 +135,5 @@ read_bitvector (const char *str, int *nobj_p)
     return vec;
 }
 
-static inline bool *
-new_bool_maximise(int nobj, bool maximise_all)
-{
-    ASSUME(nobj <= 32);
-    ASSUME(nobj >= 1);
-    bool * maximise = malloc(sizeof(bool) * nobj);
-    for (int k = 0; k < nobj; k++)
-        maximise[k] = maximise_all;
-    return maximise;
-}
-
-
-
 #endif // R_PACKAGE
 #endif // EAF_INPUT_OUTPUT_H
