@@ -4,28 +4,14 @@
 
  ---------------------------------------------------------------------
 
-                       Copyright (c) 2010
+                       Copyright (c) 2010, 2025
                   Carlos M. Fonseca <cmfonsec@dei.uc.pt>
              Manuel Lopez-Ibanez <manuel.lopez-ibanez@manchester.ac.uk>
                     Luis Paquete <paquete@dei.uc.pt>
 
- This program is free software (software libre); you can redistribute
- it and/or modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2 of the
- License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful, but
- WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, you can obtain a copy of the GNU
- General Public License at:
-                 http://www.gnu.org/copyleft/gpl.html
- or by writing to:
-           Free Software Foundation, Inc., 59 Temple Place,
-                 Suite 330, Boston, MA 02111-1307 USA
+ This Source Code Form is subject to the terms of the Mozilla Public
+ License, v. 2.0. If a copy of the MPL was not distributed with this
+ file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
  ----------------------------------------------------------------------
 
@@ -61,6 +47,7 @@
 
 static int verbose_flag = 1;
 static bool union_flag = false;
+static bool contributions_flag = false;
 static char *suffix = NULL;
 
 static void usage(void)
@@ -80,18 +67,23 @@ OPTION_VERSION_STR
 " -u, --union         treat all input sets within a FILE as a single set.   \n"
 " -r, --reference=POINT use POINT as reference point. POINT must be within  \n"
 "                     quotes, e.g., \"10 10 10\". If no reference point is  \n"
-/*
-"                     given, it is taken as the maximum for each coordinate \n"
-"                     from the union of all input points.        \n"
-*/
 "                     given, it is taken as max + 0.1 * (max - min) for each\n"
 "                     coordinate from the union of all input points.        \n"
+" -c, --contributions print the exclusive contribution of each input point. \n"
 " -s, --suffix=STRING Create an output file for each input file by appending\n"
 "                     this suffix. This is ignored when reading from stdin. \n"
 "                     If missing, output is sent to stdout.                 \n"
 "\n");
 }
 
+static void
+fprint_hvc(FILE * outfile, const double * hvc, size_t n)
+{
+    for (size_t i = 0; i < n; i++)
+        fprintf(outfile, indicator_printf_format "\n", hvc[i]);
+    fprintf(outfile, "\n");
+}
+
 /*
    FILENAME: input filename. If NULL, read stdin.
 
@@ -124,11 +116,7 @@ hv_file (const char *filename, double *reference,
         filename = stdin_name;
 
     if (filename != stdin_name && suffix) {
-        size_t outfilename_len = strlen(filename) + strlen(suffix) + 1;
-        outfilename = malloc (sizeof(char) * outfilename_len);
-        strcpy (outfilename, filename);
-        strcat (outfilename, suffix);
-
+        outfilename = m_strcat(filename, suffix);
         outfile = fopen (outfilename, "w");
         if (outfile == NULL) {
             errprintf ("%s: %s\n", outfilename, strerror(errno));
@@ -175,28 +163,44 @@ hv_file (const char *filename, double *reference,
         }
     }
 
+    if (needs_minimum) {
+        free(minimum);
+        free(maximum);
+    }
+
     if (verbose_flag >= 2) {
         printf ("# reference: ");
         vector_printf (reference, nobj);
         printf ("\n");
     }
 
+    double * hvc = NULL;
     for (n = 0, cumsize = 0; n < nruns; cumsize = cumsizes[n], n++) {
         Timer_start ();
-
-        double volume = fpli_hv (&data[nobj * cumsize], nobj, cumsizes[n] - cumsize, reference);
-
+        double volume, time_elapsed;
+        if (contributions_flag) {
+            hvc = realloc(hvc, (cumsizes[n] - cumsize) * sizeof(*hvc));
+            volume = hv_contributions(hvc, &data[nobj * cumsize], nobj, cumsizes[n] - cumsize, reference);
+        } else {
+            volume = fpli_hv(&data[nobj * cumsize], nobj, cumsizes[n] - cumsize, reference);
+        }
         if (volume == 0.0) {
             errprintf ("none of the points strictly dominates the reference point\n");
             exit (EXIT_FAILURE);
         }
-
-        double time_elapsed = Timer_elapsed_virtual ();
-
-        fprintf (outfile, indicator_printf_format "\n", volume);
+        time_elapsed = Timer_elapsed_virtual();
+        if (contributions_flag) {
+            fprint_hvc(outfile, hvc, cumsizes[n] - cumsize);
+        } else {
+            fprintf (outfile, indicator_printf_format "\n", volume);
+        }
         if (verbose_flag >= 2)
             fprintf (outfile, "# Time: %f seconds\n", time_elapsed);
     }
+    if (contributions_flag)
+        free(hvc);
+    free(data);
+    free(cumsizes);
 
     if (outfilename) {
         if (verbose_flag)
@@ -204,19 +208,13 @@ hv_file (const char *filename, double *reference,
         fclose (outfile);
         free (outfilename);
     }
-    free (data);
-    free (cumsizes);
-    if (needs_minimum) {
-        free (minimum);
-        free (maximum);
-    }
     *nobj_p = nobj;
 }
 
 int main(int argc, char *argv[])
 {
     /* See the man page for getopt_long for an explanation of these fields.  */
-    static const char short_options[] = "hVvqur:s:S";
+    static const char short_options[] = "hVvqucr:s:S";
     static const struct option long_options[] = {
         {"help",       no_argument,       NULL, 'h'},
         {"version",    no_argument,       NULL, 'V'},
@@ -224,6 +222,7 @@ int main(int argc, char *argv[])
         {"quiet",      no_argument,       NULL, 'q'},
         {"reference",  required_argument, NULL, 'r'},
         {"union",      no_argument,       NULL, 'u'},
+        {"contributions", no_argument,    NULL, 'c'},
         {"suffix",     required_argument, NULL, 's'},
         {NULL, 0, NULL, 0} /* marks end of list */
     };
@@ -238,38 +237,36 @@ int main(int argc, char *argv[])
     while (0 < (opt = getopt_long (argc, argv, short_options,
                                    long_options, &longopt_index))) {
         switch (opt) {
-        case 'r': // --reference
-            reference = read_point(optarg, &nobj);
-            if (reference == NULL) {
-                errprintf ("invalid reference point '%s'",
-                           optarg);
-                exit (EXIT_FAILURE);
-            }
-            break;
+          case 'r': // --reference
+              reference = robust_read_point(optarg, &nobj, "invalid reference point '%s'");
+              break;
 
-        case 'u': // --union
-            union_flag = true;
-            break;
+          case 'u': // --union
+              union_flag = true;
+              break;
 
-        case 's': // --suffix
-            suffix = optarg;
-            break;
+          case 'c': // --contributions
+              contributions_flag = true;
+              break;
 
-        case 'q': // --quiet
-            verbose_flag = 0;
-            break;
+          case 's': // --suffix
+              suffix = optarg;
+              break;
 
-        case 'v': // --verbose
-            verbose_flag = 2;
-            break;
+          case 'q': // --quiet
+              verbose_flag = 0;
+              break;
 
-        default:
-            default_cmdline_handler(opt);
+          case 'v': // --verbose
+              verbose_flag = 2;
+              break;
+
+          default:
+              default_cmdline_handler(opt);
         }
     }
 
     int numfiles = argc - optind;
-
     if (numfiles < 1) /* Read stdin.  */
         hv_file (NULL, reference, NULL, NULL, &nobj);
     else if (numfiles == 1) {
